==> nextcloud-26.0.11p1.tgz: nextcloud/apps/systemtags/l10n/is.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Kerfismerkinu %1$s var bætt við af kerfinu",
    "Added system tag {systemtag}" : "Bætti við kerfismerkinu {systemtag}",
    "Added system tag %1$s" : "Bætti við kerfismerkinu %1$s",
    "%1$s added system tag %2$s" : "%1$s bætti við kerfismerkinu %2$s",
    "{actor} added system tag {systemtag}" : "{actor} bætti við kerfismerkinu {systemtag}",
    "System tag %1$s removed by the system" : "Kerfismerkið %1$s var fjarlægt af kerfinu",
    "Removed system tag {systemtag}" : "Fjarlægði kerfismerkið {systemtag}",
    "Removed system tag %1$s" : "Fjarlægði kerfismerkið %1$s",
    "%1$s removed system tag %2$s" : "%1$s fjarlægði kerfismerkið %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjarlægði kerfismerkið {systemtag}",
    "You created system tag %1$s" : "Þú bjóst til kerfismerkið %1$s",
    "You created system tag {systemtag}" : "Þú bjóst til kerfismerkið {systemtag}",
    "%1$s created system tag %2$s" : "%1$s bjó til kerfismerkið %2$s",
    "{actor} created system tag {systemtag}" : "{actor} bjó til kerfismerkið {systemtag}",
    "You deleted system tag %1$s" : "Þú eyddir kerfismerkinu %1$s",
    "You deleted system tag {systemtag}" : "Þú eyddir kerfismerkinu {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eyddi kerfismerkinu %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eyddi kerfismerkinu {systemtag}",
    "You updated system tag %2$s to %1$s" : "Þú uppfærðir kerfismerkið %1$s í %2$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Þú uppfærðir kerfismerkið {oldsystemtag} í {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppfærði kerfismerkið %3$s í %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppfærði kerfismerkið {oldsystemtag} í {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Kerfismerkinu %2$s var bætt við %1$s af kerfinu",
    "System tag {systemtag} was added to {file} by the system" : "Kerfismerkinu {systemtag} var bætt við {file} af kerfinu",
    "You added system tag %2$s to %1$s" : "Þú bættir við kerfismerkinu %1$s í %2$s",
    "You added system tag {systemtag} to {file}" : "Þú bættir við kerfismerkinu {systemtag} í {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s bætti við kerfismerkinu %3$s í %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} bætti við kerfismerkinu {systemtag} í {file}",
    "System tag %2$s was removed from %1$s by the system" : "Kerfismerkið %2$s var fjarlægt af %1$s af kerfinu",
    "System tag {systemtag} was removed from {file} by the system" : "Kerfismerkið {systemtag} var fjarlægt af {file} af kerfinu",
    "You removed system tag %2$s from %1$s" : "Þú fjarlægðir kerfismerkið %2$s af %1$s",
    "You removed system tag {systemtag} from {file}" : "Þú fjarlægðir kerfismerkið {systemtag} af {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjarlægði kerfismerkið %3$s af %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjarlægði kerfismerkið {systemtag} af {file}",
    "%s (restricted)" : "%s (takmarkaður aðgangur)",
    "%s (invisible)" : "%s (ósýnilegt)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Kerfismerkjum</strong> á skrá hefur verið breytt",
    "Tags" : "Merki",
    "All tagged %s …" : "Allt merkt %s …",
    "tagged %s" : "merkt %s",
    "Collaborative tags" : "Samstarfsmerkingar",
    "Collaborative tagging functionality which shares tags among users." : "Samstarfsmerkingareiginleiki sem deilir merkjum á milli notenda.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samstarfsmerkingareiginleiki sem deilir merkjum á milli notenda. Frábært fyrir hópvinnu.\n\t(Ef þú ert þjónustuaðili með margar uppsetningar á sömu þjónum, þá er ráðlagt að gera þetta óvirkt því merkin eru sameiginleg.)",
    "Create or edit tags" : "Búa til eða breyta merki",
    "Search for a tag to edit" : "Leita að merki til að breyta",
    "Collaborative tags …" : "Samstarfsmerki …",
    "No tags to select" : "Engin merki til að velja",
    "Tag name" : "Heiti merkis",
    "Tag level" : "Stig merkis",
    "Create" : "Búa til",
    "Update" : "Uppfæra",
    "Delete" : "Eyða",
    "Reset" : "Endurstilla",
    "Loading …" : "Hleð inn …",
    "Public" : "Opinbert",
    "Restricted" : "Takmarkað",
    "Invisible" : "Ósýnilegt",
    "Created tag" : "Bjó til merki",
    "Failed to create tag" : "Mistókst að búa til merki",
    "Updated tag" : "Uppfærði merki",
    "Failed to update tag" : "Mistókst að uppfæra merki",
    "Deleted tag" : "Eyddi merki",
    "Failed to delete tag" : "Mistókst að eyða merki",
    "Loading collaborative tags …" : "Hleð inn samstarfsmerkjum …",
    "Search or create collaborative tags" : "Búa til eða breyta samstarfsmerkjum",
    "No tags to select, type to create a new tag" : "Engin merki til að velja, skrifaðu til að útbúa nýtt merki",
    "Failed to load tags" : "Mistókst að hlaða inn merkjum",
    "Failed to load selected tags" : "Mistókst að hlaða inn völdum merkjum",
    "Failed to select tag" : "Ekki tókst að velja merki",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samstarfsmerkingar eru tiltækar öllum notendum. Takmörkuð merki sjá allir notendur en þeir geta ekki úthlutað þeim. Ósýnileg merki eru fyrir notkun innan kerfis, þar sem notendur munu ekki sjá þau eða getað úthlutað þeim.",
    "This file has the tag {tag}" : "Þessi skrá er með merkið {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Þessi skrá er með merkin {firstTags} og {lastTag}",
    "List of tags and their associated files and folders." : "Listi yfir merki og þeim tengdar skrár og möppur.",
    "No tags found" : "Engin merki fundust",
    "Tags you have created will show up here." : "Merki sem þú hefur útbúið munu birtast hér.",
    "Failed to load last used tags" : "Mistókst að hlaða inn síðast notuðu merkjum",
    "Missing \"Content-Location\" header" : "Vantar \"Content-Location\"-haus",
    "Failed to load tags for file" : "Mistókst að hlaða inn merkjum af skrá",
    "Failed to set tag for file" : "Mistókst að setja merki á skrá",
    "Failed to delete tag for file" : "Mistókst að eyða merki á skrá",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "Tag name is empty" : "Nafn merkis vantar",
    "Select tag …" : "Veldu merki ...",
    "Tagged files" : "Merktar skrár",
    "Select tags to filter by" : "Veldu merki til að sía eftir",
    "Please select tags to filter by" : "Veldu merki til að sía eftir",
    "No files found for the selected tags" : "Engar skrár fundust með völdum merkjum",
    "Create a new tag" : "Búa til nýtt merki"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-27.1.3.tgz: nextcloud/apps/systemtags/l10n/is.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Nafn merkis vantar",
    "Update" : "Uppfæra",
    "Create" : "Búa til",
    "Select tag …" : "Veldu merki ...",
    "System tag %1$s added by the system" : "Kerfismerkinu %1$s var bætt við af kerfinu",
    "Added system tag {systemtag}" : "Bætti við kerfismerkinu {systemtag}",
    "Added system tag %1$s" : "Bætti við kerfismerkinu %1$s",
    "%1$s added system tag %2$s" : "%1$s bætti við kerfismerkinu %2$s",
    "{actor} added system tag {systemtag}" : "{actor} bætti við kerfismerkinu {systemtag}",
    "System tag %1$s removed by the system" : "Kerfismerkið %1$s var fjarlægt af kerfinu",
    "Removed system tag {systemtag}" : "Fjarlægði kerfismerkið {systemtag}",
    "Removed system tag %1$s" : "Fjarlægði kerfismerkið %1$s",
    "%1$s removed system tag %2$s" : "%1$s fjarlægði kerfismerkið %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjarlægði kerfismerkið {systemtag}",
    "You created system tag %1$s" : "Þú bjóst til kerfismerkið %1$s",
    "You created system tag {systemtag}" : "Þú bjóst til kerfismerkið {systemtag}",
    "%1$s created system tag %2$s" : "%1$s bjó til kerfismerkið %2$s",
    "{actor} created system tag {systemtag}" : "{actor} bjó til kerfismerkið {systemtag}",
    "You deleted system tag %1$s" : "Þú eyddir kerfismerkinu %1$s",
    "You deleted system tag {systemtag}" : "Þú eyddir kerfismerkinu {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eyddi kerfismerkinu %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eyddi kerfismerkinu {systemtag}",
    "You updated system tag %2$s to %1$s" : "Þú uppfærðir kerfismerkið %1$s í %2$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Þú uppfærðir kerfismerkið {oldsystemtag} í {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppfærði kerfismerkið %3$s í %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppfærði kerfismerkið {oldsystemtag} í {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Kerfismerkinu %2$s var bætt við %1$s af kerfinu",
    "System tag {systemtag} was added to {file} by the system" : "Kerfismerkinu {systemtag} var bætt við {file} af kerfinu",
    "You added system tag %2$s to %1$s" : "Þú bættir við kerfismerkinu %1$s í %2$s",
    "You added system tag {systemtag} to {file}" : "Þú bættir við kerfismerkinu {systemtag} í {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s bætti við kerfismerkinu %3$s í %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} bætti við kerfismerkinu {systemtag} í {file}",
    "System tag %2$s was removed from %1$s by the system" : "Kerfismerkið %2$s var fjarlægt af %1$s af kerfinu",
    "System tag {systemtag} was removed from {file} by the system" : "Kerfismerkið {systemtag} var fjarlægt af {file} af kerfinu",
    "You removed system tag %2$s from %1$s" : "Þú fjarlægðir kerfismerkið %2$s af %1$s",
    "You removed system tag {systemtag} from {file}" : "Þú fjarlægðir kerfismerkið {systemtag} af {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjarlægði kerfismerkið %3$s af %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjarlægði kerfismerkið {systemtag} af {file}",
    "%s (restricted)" : "%s (takmarkaður aðgangur)",
    "%s (invisible)" : "%s (ósýnilegt)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Kerfismerkjum</strong> á skrá hefur verið breytt",
    "Tags" : "Merki",
    "Collaborative tags" : "Samstarfsmerkingar",
    "Collaborative tagging functionality which shares tags among users." : "Samstarfsmerkingareiginleiki sem deilir merkjum á milli notenda.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samstarfsmerkingareiginleiki sem deilir merkjum á milli notenda. Frábært fyrir hópvinnu.\n\t(Ef þú ert þjónustuaðili með margar uppsetningar á sömu þjónum, þá er ráðlagt að gera þetta óvirkt því merkin eru sameiginleg.)",
    "Failed to load tags" : "Mistókst að hlaða inn merkjum",
    "No tags found" : "Engin merki fundust",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samstarfsmerkingar eru tiltækar öllum notendum. Takmörkuð merki sjá allir notendur en þeir geta ekki úthlutað þeim. Ósýnileg merki eru fyrir notkun innan kerfis, þar sem notendur munu ekki sjá þau eða getað úthlutað þeim.",
    "Create a new tag" : "Búa til nýtt merki",
    "Name" : "Heiti",
    "Public" : "Opinbert",
    "Restricted" : "Takmarkað",
    "Invisible" : "Ósýnilegt",
    "Delete" : "Eyða",
    "Reset" : "Endurstilla",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "Tagged files" : "Merktar skrár",
    "Select tags to filter by" : "Veldu merki til að sía eftir",
    "Please select tags to filter by" : "Veldu merki til að sía eftir",
    "No files found for the selected tags" : "Engar skrár fundust með völdum merkjum"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
